@@ -1,5 +1,5 @@
 
-from typing import Any, Callable, Dict
+from typing import Any, Callable
 
 from aio.api.github import interface
 
@@ -10,7 +10,7 @@ UNSET = object()
 class GithubEntity:
     """Base Github entity class."""
 
-    def __init__(self, github: interface.IGithubAPI, data: Dict) -> None:
+    def __init__(self, github: interface.IGithubAPI, data: dict) -> None:
         self.data = data
         self._github = github
 
@@ -20,7 +20,7 @@ class GithubEntity:
         return self._github
 
     @property
-    def __data__(self) -> Dict[str, Callable]:
+    def __data__(self) -> dict[str, Callable]:
         """Dictionary of callables to mangle corresponding `self.data` keys."""
         return {}
 
@@ -38,7 +38,7 @@ class GithubEntity:
 class GithubRepoEntity(GithubEntity):
     """Base Github repo entity class."""
 
-    def __init__(self, repo: interface.IGithubRepo, data: Dict) -> None:
+    def __init__(self, repo: interface.IGithubRepo, data: dict) -> None:
         self.data = data
         self._repo = repo
 
